/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/


package com.ael.crm.metier;

import java.util.Date;
import java.text.SimpleDateFormat;

/**
 * Une classe modélisant une résolution
 * @author jm
 *
 */
public class Resolution {
	
	private int idResolution;
	private String evenement;
	private String statut;
	private String priorite;
	private String responsable;
	private String description;
	private long dateEvenement = 0;

	/**
	 * Construit une <code>Resolution</code>
	 * 
	 * @param	id_					identifiant entier de la résolution
	 * @param 	responsable_ 		responsable de la résolution
	 * @param	statut_				statut de la résolution
	 * @param	priorite_			priorité de la résolution
	 * @param 	evenement_			évènement de la résolution
	 * @param	description_		description de la résolution
	 * @param	dateEvenement_      date et heure de l'évènement en ms	
	 */
	public Resolution (int id_,
			           String responsable_,
			           String statut_,
			           String priorite_,
			           String evenement_,
			           String description_,
			           long dateEvenement_) {
		idResolution = id_;
		responsable = responsable_;
		statut = statut_;
		priorite = priorite_;
		evenement = evenement_;
		description = description_;
		dateEvenement = dateEvenement_;
	}
	
	/**
	 * Construit une <code>Resolution</code>
	 * 
	 * @param	id_		identifiant entier de la résolution
	 */
	public Resolution(int id_) {
		this(id_, "", "",  "", "", "", 0);
	}
	
	public void setIdResolution(int id) { idResolution = id; }
	public void setResponsable(String resp_) { responsable = resp_; }
	public void setStatut(String statut_) { statut = statut_; }
	public void setPriorite(String priorite_) { priorite = priorite_; }
	public void setEvenement(String evt) { evenement = evt; }
	public void setDescription(String desc) { description = desc; }
	public void setDateEvenement(long dateEvt) { dateEvenement = dateEvt; }
	
	public int getIdResolution() { return idResolution; }
	public String getResponsable() { return responsable; }
	public String getStatut() { return statut; }
	public String getPriorite() { return priorite; }
	public String getEvenement() { return evenement; }
	public String getDescription() { return description; }
	public long getDateEvenement() { return dateEvenement; }
	
	public String getDateEvenementFormatee() {
		SimpleDateFormat formatDate = new SimpleDateFormat("dd-MM-yyyy HH:mm");
		return formatDate.format(new Date(dateEvenement));
	}
}

