/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

package com.ael.util;

import java.util.Vector;

import javax.print.DocFlavor;
import javax.print.PrintService;
import javax.print.PrintServiceLookup;
import javax.print.attribute.HashPrintServiceAttributeSet;
import javax.print.attribute.PrintRequestAttributeSet;
import javax.print.attribute.HashPrintRequestAttributeSet;
import javax.print.attribute.PrintServiceAttributeSet;
import javax.print.attribute.standard.Copies;
import javax.print.attribute.standard.MediaSizeName;
import javax.print.attribute.standard.PrinterName;

import net.sf.jasperreports.engine.JRException;
import net.sf.jasperreports.engine.JRExporterParameter;
import net.sf.jasperreports.engine.JasperPrint;
import net.sf.jasperreports.engine.JasperPrintManager;
import net.sf.jasperreports.engine.export.JRPrintServiceExporter;
import net.sf.jasperreports.engine.export.JRPrintServiceExporterParameter;;

/**
 * Classe d'outillage de repérage des imprimantes serveur
 * 
 * @author jm
 */
public class Imprimantes {
	
	/**
	 * Repérer la liste des imprimantes pouvant imprimer à partir d'un tableau d'octets
	 * @return	Un vecteur de la liste des imprimantes trouvées
	 */
	public static Vector<String> listerImprimantesPdf() {
		DocFlavor flavor = DocFlavor.BYTE_ARRAY.PDF;
		PrintRequestAttributeSet aset = new HashPrintRequestAttributeSet();
		aset.add(MediaSizeName.ISO_A4);
		PrintService[] serviceImpression = PrintServiceLookup.lookupPrintServices(flavor, aset);
		Vector<String> imprimantes = new Vector<String>();
		try {
			for (int i = 0; i < serviceImpression.length; i++)
				imprimantes.add(serviceImpression[i].getName());
		} catch (Exception x) {
			x.printStackTrace();
		}
		
		return imprimantes;
	}

	/**
	 * Imprimer un rapport JasperReports
	 * 
	 * @param jrprint 			Le JasperPrint issu du JasperReport
	 * @param nomImprimante		Le nom de l'imprimante vers laquelle est envoyé le rapport. Une chaîne
	 * 							vide envoie vers l'imprimante par défaut.
	 * @throws JRException
	 */
	public static void imprimerJR(JasperPrint jrprint, String nomImprimante) throws JRException {
		imprimerJR(jrprint, nomImprimante, null);
	}
	
	/**
	 * Imprimer un rapport JasperReports
	 * 
	 * @param jrprint 			Le JasperPrint issu du JasperReport
	 * @param nomImprimante		Le nom de l'imprimante vers laquelle est envoyé le rapport. Une chaîne
	 * 							vide envoie vers l'imprimante par défaut.
	 * @param mediaSize			un MediaSizeName représentant les dimensions de la page imprimable
	 * @throws JRException
	 */
	public static void imprimerJR(JasperPrint jrprint, String nomImprimante, MediaSizeName mediaSize) throws JRException {
		if (nomImprimante.equals("") || nomImprimante == null)
			JasperPrintManager.printReport(jrprint, false);
		else { // choisir l'imprimante
			PrintRequestAttributeSet requestAttributeSet = new HashPrintRequestAttributeSet();
			//MediaSizeName mediaSizeName = MediaSize.findMedia(80, 125,MediaPrintableArea.MM);
			if (mediaSize != null)
				requestAttributeSet.add(mediaSize);
			//requestAttributeSet.add(MediaSizeName.ISO_B7); // 88x125 mm
			requestAttributeSet.add(new Copies(1));
			
			/* Utiliser l'imprimante pour l'exporteur */
			PrintServiceAttributeSet serviceAttributeSet = new HashPrintServiceAttributeSet();
			serviceAttributeSet.add(new PrinterName(nomImprimante, null)); 
			
			JRPrintServiceExporter exporter = new JRPrintServiceExporter();
			exporter.setParameter(JRExporterParameter.JASPER_PRINT, jrprint);
			/* Utiliser l'imprimante pour l'exporteur */
			exporter.setParameter(JRPrintServiceExporterParameter.PRINT_SERVICE_ATTRIBUTE_SET, serviceAttributeSet);
			exporter.setParameter(JRPrintServiceExporterParameter.PRINT_REQUEST_ATTRIBUTE_SET, requestAttributeSet);
			exporter.setParameter(JRPrintServiceExporterParameter.DISPLAY_PAGE_DIALOG, Boolean.FALSE);
			exporter.setParameter(JRPrintServiceExporterParameter.DISPLAY_PRINT_DIALOG, Boolean.FALSE);
			exporter.exportReport();
		}
	}
	
}
